# -*- coding: utf-8 -*-
from __future__ import unicode_literals
# Generated by Django 1.10 on 2016-09-14 18:21
from __future__ import unicode_literals

from django.db import migrations
import django.db.models.deletion
import djangoplus.admin.models
import djangoplus.db.models.fields


class Migration(migrations.Migration):

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
        ('admin', '0002_log_logindex'),
    ]

    operations = [
        migrations.CreateModel(
            name='ContentType',
            fields=[
            ],
            options={
                'proxy': True,
            },
            bases=('contenttypes.contenttype',),
            managers=[
                ('objects', djangoplus.admin.models.ContentTypeManager()),
            ],
        ),
        migrations.AlterField(
            model_name='log',
            name='content_type',
            field=djangoplus.db.models.fields.ModelChoiceField(on_delete=django.db.models.deletion.CASCADE, to='admin.ContentType', verbose_name='Objeto'),
        ),
    ]
