{% extends "base_email.html" %}
{% block content %}
    <h1>Novo Usuário!</h1>

    <p>Você foi cadastro no sistema com o perfil de <b>Administrador</b>.<br></p>
    <p>Para acessar o sistema clique no botão abaixo e fornecessa suas credenciais de acesso.</p>

    <a href="#" style="background-color:#D84A38;color:#ffffff;display:inline-block;font-family:sans-serif;font-size:13px;font-weight:bold;line-height:33px;text-align:center;text-decoration:none;width:130px;-webkit-text-size-adjust:none;">Acessar agora!</a>
{% endblock %}


{% block extra %}

    <h2>Acesse através do seu celular!</h2>
    <p>You'll be the first to hear about new arrivals, exclusive promotionas, cool collaborations, and the latest in everything.</p>
    <p class="center"><img alt="qrcode" src="https://lh3.googleusercontent.com/JhlUkFmf_qYUMEV_H-WPvG_TMB7oiSY8jqqRIkzJ_cZRe0eWYIx_x59NPMX-gMpUSRZN=w170"/></p>

{% endblock %}