# -*- coding: utf-8 -*-
from __future__ import unicode_literals
# Generated by Django 1.10 on 2016-09-10 10:09
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import djangoplus.db.models.fields


class Migration(migrations.Migration):

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
        ('admin', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Log',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('operation', djangoplus.db.models.fields.IntegerField(choices=[[1, 'Cadastro'], [2, 'Edi\xe7\xe3o'], [3, 'Exclus\xe3o']], verbose_name='Opera\xe7\xe3o')),
                ('date', djangoplus.db.models.fields.DateTimeField(auto_now=True, verbose_name='Data/Hora')),
                ('object_id', djangoplus.db.models.fields.IntegerField(verbose_name='Identificador')),
                ('object_description', djangoplus.db.models.fields.CharField(max_length=255, verbose_name='Descri\xe7\xe3o do Objeto')),
                ('content', djangoplus.db.models.fields.TextField(null=True, verbose_name='Conte\xfado')),
                ('content_type', djangoplus.db.models.fields.ModelChoiceField(on_delete=django.db.models.deletion.CASCADE, to='contenttypes.ContentType', verbose_name='Objeto')),
                ('user', djangoplus.db.models.fields.ModelChoiceField(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'Log',
                'verbose_name_plural': 'Logs',
            },
        ),
        migrations.CreateModel(
            name='LogIndex',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('object_id', djangoplus.db.models.fields.IntegerField(verbose_name='Identificador')),
                ('content_type', djangoplus.db.models.fields.ModelChoiceField(on_delete=django.db.models.deletion.CASCADE, to='contenttypes.ContentType', verbose_name='Dado')),
                ('log', djangoplus.db.models.fields.ModelChoiceField(on_delete=django.db.models.deletion.CASCADE, to='admin.Log', verbose_name='Log')),
            ],
            options={
                'verbose_name': 'Index',
                'verbose_name_plural': 'Indexes',
            },
        ),
    ]
