# -*- coding: utf-8 -*-
from __future__ import unicode_literals
# Generated by Django 1.10 on 2016-10-09 23:50
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import djangoplus.db.models.fields


class Migration(migrations.Migration):

    dependencies = [
        ('admin', '0005_auto_20161005_1536'),
    ]

    operations = [
        migrations.CreateModel(
            name='Organization',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('ascii', djangoplus.db.models.fields.SearchField(blank=True, default=b'', editable=False)),
            ],
            options={
                'verbose_name': 'Organiza\xe7\xe3o',
                'verbose_name_plural': 'Organiza\xe7\xf5es',
            },
        ),
        migrations.CreateModel(
            name='OrganizationRole',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('organization', djangoplus.db.models.fields.ModelChoiceField(on_delete=django.db.models.deletion.CASCADE, to='admin.Organization', verbose_name='Organiza\xe7\xe3o')),
                ('role', djangoplus.db.models.fields.ModelChoiceField(on_delete=django.db.models.deletion.CASCADE, to='admin.Role', verbose_name='Fun\xe7\xe3o')),
            ],
            options={
                'verbose_name': 'Papel na Organiza\xe7\xe3o',
                'verbose_name_plural': 'Papeis na Organiza\xe7\xe3o',
            },
        ),
    ]
